Learn R Programming

Pv3Rs (version 1.0.0)

fs_VHX_BPD: Allele frequencies computed using example Plasmodium vivax data

Description

The posterior mean of a multinomial-Dirichlet model with uniform prior fit to data on allele prevalence in initial episodes of ys_VHX_BPD. Because the model is fit to allele prevalence (observed) not allele frequency ( requires integrating-out unknown multiplicities of infection) it is liable to underestimate the frequencies of common alleles and overestimate those of rare but detected alleles.

Usage

fs_VHX_BPD

Arguments

Format

A list of nine markers; for each marker a named vector of allele frequencies that sum to one.