Plot malaria parasite genetic data on two or more episodes. Compute per-person posterior probabilities that each Plasmodium vivax (Pv) recurrence is a recrudescence, relapse, or reinfection (3Rs) using per-person P. vivax genetic data on two or more episodes and a statistical model described in Taylor, Foo and White (2022) tools:::Rd_expr_doi("10.1101/2022.11.23.22282669"). Plot per-recurrence posterior probabilities.
Maintainer: Aimee Taylor aimee.taylor@pasteur.fr (ORCID)
Authors:
Yong See Foo (ORCID)
Other contributors:
Tymoteusz Kwiecinski (compiled included macros.Rd) [compiler]
Duncan Murdoch (author of included macros.Rd) [contributor]
Mans Magnusson (author of included msg_progress_bar.R) [contributor]
Institut Pasteur [copyright holder]
European Union, Project 101110393 [funder]
Useful links: