Previously-published microsatellite data on P. vivax parasites extracted from study participants enrolled in the Best Primaquine Dose (BPD) and Vivax History (VHX) trials; see Taylor & Watson et al. 2019 (tools:::Rd_expr_doi("doi:10.1038/s41467-019-13412-x")) for more details of the genetic data; for more details of the VHX and BPD trials, see Chu et al. 2018a (tools:::Rd_expr_doi("doi:10.1093/cid/ciy319")) and Chu et al. 2018b (tools:::Rd_expr_doi("doi:10.1093/cid/ciy735")).
ys_VHX_BPDA list of 217 study participants; for each study participant, a list of one or more episodes; for each episode, a list of three or more microsatellite markers; for each marker, a vector of observed alleles (repeat lengths). For example:
Study participant identifier: study participant 103 in the BPD trial
Episode identifier: episode one of study participant 103 in the BPD trial
Marker identifier: P. vivax 3.27
Allele identifier: 18 repeat lengths